# GrooveMat

Get your atoms moving!

## Overview

This software package uses the Crystal Graph Convolutional Neural Networks (CGCNN) framework and M3gnet to create an un-supervised GNN that converges the internal degrees of freedom of a crystal lattice. The package is very simple, allowing you to train the model and predict converged cif files! 

## Download

To download disco, use the command below

```
pip install groovemat
```

To get an overview of the commands, run the following command

```
groovemat --help
```

## Results

Below is a table containing some of the results gathered from the program.

| CIF ID     | Mean Error (Å) | Max Error (Å) |
| :---------- | :--------------: | -------------: |
| Nd1 In1 O3 | 0.0087         | 0.0125        |
| Np1 Be1 O3 | 0.0061         | 0.0074        |
| Mn3 Au1 N1 | 0.0039         | 0.0076        |
| Na1 Li1 O3 | 0.0077         | 0.0095        |
| La1 Cr1 O3 | 0.0088         | 0.0135        |



# Download

```
pip install groovemat
```

